@@ -118,10 +118,10 @@ sub add {
     $self->addRTCP( $data );
   } elsif( ref( $data ) eq "Mwalk::MTrace" ) {
     $self->addMTrace( $data );
-  } elsif( ref( $data ) eq "Mwalk::Traceroute" ) {
+  } elsif( ref( $data ) eq "Mwalk::TraceRoute" ) {
     $self->addUTrace( $data );
   } else {
-    die "Asked to add an invalid component to a receiver"; 
+    die "Asked to add an invalid component to a receiver: ", ref( $data ); 
   }
 }
 
