@@ -9,7 +9,7 @@
   Content : A compund visitor which runs a pair of visitors, one walking up 
             the tree and a second which walks back down.
              
-  $Id: GlobalVisitor.java,v 1.6 2001/08/22 17:44:21 robertc Exp $
+  $Id: GlobalVisitor.java,v 1.7 2002/05/10 18:07:57 robertc Exp $
 */
 
 package mwalk.visitor;
@@ -21,7 +21,6 @@ import java.util.Enumeration;
 import mwalk.core.Tree;
 import mwalk.core.TreeNode;
 import mwalk.core.Receiver;
-import mwalk.eval.PrimaryPathEvaluator;
 import mwalk.util.VisitException;
 
 
@@ -332,12 +331,5 @@ public class GlobalVisitor extends AbstractVisitor implements UpVisitor, DownVis
     public TreeNode[] getChildren( Tree tree, TreeNode node ) {
 
 	return( dv.getChildren( tree, node ) );
-	/*
-	if( ! ((AbstractVisitor)dv).markSeen( node ) )
-	    // get a list of all child links active by primary route
-	    return( node.getActiveChildren( new PrimaryPathEvaluator() ) );
-	else
-	    return( new TreeNode[0] );
-	*/
     }
 }
