@@ -85,8 +85,8 @@ public class LinkCountVisitor extends PrintVisitor implements DownVisitor {
      */
     public boolean init( Tree tree ) {
 
-	// setup a primary path evaluator
-	evaluator( new mwalk.eval.PrimaryPathEvaluator() );
+	// setup a primary tree evaluator
+	evaluator( new mwalk.eval.PrimaryTreeEvaluator() );
 
 	// set source at depth zero
 	tree.getSource().data.put( "depth", new Integer( 0 ) );
