@@ -26,17 +26,13 @@ import mwalk.util.VisitException;
  * @author Robert Chalmers
  * @version 1.0 
  */
-public abstract class MetricVisitor extends PrintVisitor implements DownVisitor {
+public abstract class MetricVisitor extends PeriodicVisitor implements DownVisitor {
 
     /** Base of keys in configuration file */
     private static final String CFG_BASE = "MetricVisitor.";
     /** Default file name if none supplied */
     private static final String DEF_FILENAME = "tree-metric";
 
-    protected long time = 0;
-    protected double timeval = 0;
-    protected double offset = 0;
-    protected long periods = 0;
 
     /**
      * Default constructor.
@@ -63,9 +59,7 @@ public abstract class MetricVisitor extends PrintVisitor implements DownVisitor
      */
     public MetricVisitor( long periods ) {
 
-	super( DEF_FILENAME );
-
-	this.periods = periods;
+	super( DEF_FILENAME, periods );
     }
 
     /**
@@ -76,32 +70,7 @@ public abstract class MetricVisitor extends PrintVisitor implements DownVisitor
      */
     public MetricVisitor( String filename, long periods ) {
 
-	super( filename );
-
-	this.periods = periods;
-    }
-
-
-    public long getTime() {
-
-	return( time );
-    }
-
-    public long incTime() {
-
-	timeval += offset;
-	return( time = (long)timeval );
-    }
-
-    public void setTime( double tv ) {
-
-	timeval = tv;
-	time = (long)tv;
-    }
-
-    public void startTime( Tree tree ) {
-
-	setTime( (double)tree.getStart() );
+	super( filename, periods );
     }
 
 
@@ -115,62 +84,6 @@ public abstract class MetricVisitor extends PrintVisitor implements DownVisitor
 	return( true );
     }
 
-    /**
-     * Initialize the visitor state.
-     *
-     * @param <code>Tree</code> current tree instance
-     */
-    public boolean init( Tree tree ) {
-
-	// get period from config file if not already set
-	if( periods == 0 ) {
-	    periods = cfgInt( CFG_BASE + "periods" );
-	    if( periods <= 0 )
-		periods = 1;
-	}
-
-	// get the start time for the simulation and compute the incremental offset to use
-	startTime( tree );
-	if( periods > 1 )
-	    // set offset to include enough periods hitting both start and stop times
-	    offset = (double)(tree.getStop() - tree.getStart()) / (double)(periods - 1);
-	else
-	    // set offset to push beyond stop time
-	    offset = (double)(tree.getStop() - tree.getStart() + 1);
-
-	Config.verbose( this, "\nComputing metrics at time " + time );
-
-	return( super.init( tree ) );
-    }
-
-    /**
-     * Check whether the visitor wants another pass over the tree.
-     *
-     * @param <code>Tree</code> vistited tree 
-     * @return <code>boolean</code> whether to walk again
-     */
-    public boolean again( Tree tree ) {
-
-	try {
-	    process( tree );
-
-	} catch( VisitException ve ) {
-	    Config.verbose( ve.getMessage() );
-	    return( false );
-	}
-
-	// reset for the next pass (if more time)
-	reset( tree );
-	if( incTime() <= tree.getStop() ) {
-	    Config.verbose( this, "\nComputing metrics at time " + time );
-	    return( true );
-	} else {
-	    startTime( tree );
-	    return( false );
-	}
-    }
-
-
     /**
      * Visit the current node prior to visiting children.
      * This method is called if prefix() returns true.
@@ -218,25 +131,13 @@ public abstract class MetricVisitor extends PrintVisitor implements DownVisitor
     }
 
     /**
-     * Get a list of children for the current node applying correct activity
-     * semantics.
+     * Actually perform visit in derived class.
      *
      * @param <code>Tree</code> current tree instance
      * @param <code>TreeNode</code> current node
-     * @return <code>TreeNode[]</code> list of active children nodes
+     * @param <code>Vector</code> list of return values passed back along the path
+     * @return <code>Object</code> optional return value to pass back along the path
+     * @exception <code>VisitException</code> if a problem ocurred during visit
      */
-    public TreeNode[] getChildren( Tree tree, TreeNode node ) {
-
-	// check if this node has already been seen
-	if( ! markSeen( node ) ) {
-	    // get all children on active links for the current time
-	    return( node.getActiveChildren( eval, time ) );
-	} else
-	    return( new TreeNode[0] );
-    }
-
-
     protected abstract MetricCount doVisit( Tree tree, TreeNode node, Vector list ) throws VisitException;
-
-    protected abstract void process( Tree tree ) throws VisitException;
 }
